@@ -21,11 +21,21 @@ def main(config_path):
         bufferPath = "bufferdata.json"
         if "/" in config_path:
             bufferPath = "/".join(config_path.split("/")[:-1]) + "/bufferdata.json"
-            print(bufferPath) 
-        with open(bufferPath, "w") as fl:
-            json.dump({},fl)
+        if os.path.exists(bufferPath):
+            with open(bufferPath, "r") as f:
+                try:
+                    prev_data = json.load(f)
+                except ValueError:
+                    prev_data = {}
+
+            with open(bufferPath, "w") as fl:
+                # json.dumps(datalogs , fl)
+                json.dump(prev_data, fl)
+        else:
+
+            with open(bufferPath, "w") as fl:
+                json.dump({},fl)
 
-        print(bufferPath) 
         inp.work(config, bufferPath)
 
     except Exception as exception:
